@@ -31,6 +31,7 @@ class HardwareType(str, Enum):
     Broadwell = "Broadwell"
     Icelake = "Icelake"
     NUC_TIGER_LAKE = "Intel NUC Tiger Lake"
+    SKYLAKE_SP = "Skylake-SP"
 
     HAILO8 = "Hailo-8"
     AMBARELLA = "Ambarella"
@@ -74,57 +75,23 @@ class HardwareGroup(str, Enum):
     CONSUMER_EDGE = "Consumer Edge"
 
 
-class HardwareTypeLabel(str, Enum):
-    XAVIER = "Jetson Xavier NX 16GB"
-    NANO = "Jetson Nano 4GB"
-    XAVIER_AGX = "Jetson AGX Xavier 32GB"
-    ORIN = "Jetson AGX Orin Development Kit"
-
-    K80 = HardwareType.K80.value
-    V100 = HardwareType.V100.value
-    T4 = HardwareType.T4.value
-    A10G = HardwareType.A10G.value
-    A100_80G = HardwareType.A100_80G.value
-    A100_40G = HardwareType.A100_40G.value
-    CPU = HardwareType.CPU.value
-    EPYC = HardwareType.EPYC.value
-    EPYC_7002 = f"AMD Rome {HardwareType.EPYC_7002.value}"
-    EPYC_7003 = f"AMD Milan {HardwareType.EPYC_7003.value}"
-    CASCADE_LAKE = HardwareType.CASCADE_LAKE.value
-    SKYLAKE = "Sky Lake"
-    Broadwell = HardwareType.Broadwell.value
-    Icelake = "Ice Lake"
-    NUC_TIGER_LAKE = HardwareType.NUC_TIGER_LAKE.value
-
-    HAILO8 = HardwareType.HAILO8.value
-    AMBARELLA = HardwareType.AMBARELLA.value
-    APPLE_IPHONE_A11 = HardwareType.APPLE_IPHONE_A11.value
-    APPLE_IPHONE_A12 = HardwareType.APPLE_IPHONE_A12.value
-    APPLE_IPHONE_A14 = HardwareType.APPLE_IPHONE_A14.value
-    APPLE_IPHONE_A15 = HardwareType.APPLE_IPHONE_A15.value
-    SNAPDRAGON_845 = HardwareType.SNAPDRAGON_845.value
-    SNAPDRAGON_855 = HardwareType.SNAPDRAGON_855.value
-    SNAPDRAGON_885 = HardwareType.SNAPDRAGON_885.value
-    SNAPDRAGON_8_GEN_1 = HardwareType.SNAPDRAGON_8_GEN_1.value
-    EXYNOS_9810 = HardwareType.EXYNOS_9810.value
-    EXYNOS_9820 = HardwareType.EXYNOS_9820.value
-    EXYNOS_990 = HardwareType.EXYNOS_990.value
-    EXYNOS_2200 = HardwareType.EXYNOS_2200.value
-
-
 class HardwareMachineModel(str, Enum):
     K80 = "p2.xlarge"
     V100 = "p3.2xlarge"
     T4 = "g4dn.2xlarge"
     A10G = "g5.2xlarge"
-    CPU = "c5.4xlarge"
     EPYC = "c5a.2xlarge"
+    # CPU is deprecated, cascade_lake is relevant,
+    # python aliases duplicate enum values to the first key to use them,
+    # so cascade_lake should be before cpu. cpu's label will be broken :(, but that's fine.
+    # the reverse isn't.
     CASCADE_LAKE = "c5.4xlarge"
     SKYLAKE = "c5n.4xlarge"
     Broadwell = "m4.4xlarge"
     Icelake = "m6i.4xlarge"
     EPYC_7002 = "c5a.4xlarge"
     EPYC_7003 = "m6a.4xlarge"
+    SKYLAKE_SP = "m5.2xlarge"
 
     NANO = HardwareType.NANO.value
     XAVIER = HardwareType.XAVIER.value
@@ -148,6 +115,9 @@ class HardwareMachineModel(str, Enum):
     EXYNOS_990 = HardwareType.EXYNOS_990.value
     EXYNOS_2200 = HardwareType.EXYNOS_2200.value
 
+    # deprecated
+    CPU = "c5.4xlarge"
+
 
 class InferenceHardware(str, Enum):
     """
@@ -181,6 +151,7 @@ class MapHardwareTypeToFamily(str, Enum):
     Broadwell = InferenceHardware.CPU.value
     Icelake = InferenceHardware.CPU.value
     NUC_TIGER_LAKE = InferenceHardware.CPU.value
+    SKYLAKE_SP = InferenceHardware.CPU.value
 
 
 class InferyVersion(str, Enum):
@@ -216,6 +187,7 @@ class MapHardwareTypeToInferyVersion(str, Enum):
     Broadwell = InferyVersion.CPU.value
     Icelake = InferyVersion.CPU.value
     NUC_TIGER_LAKE = InferyVersion.CPU.value
+    SKYLAKE_SP = InferyVersion.CPU.value
 
 
 class HardwareEnvironment(str, Enum):
@@ -253,6 +225,7 @@ class HardwareTaint(str, Enum):
     Broadwell = "intel.com/broadwell"
     Icelake = "intel.com/icelake"
     NUC_TIGER_LAKE = "intel.com/nuc-tiger-lake"
+    SKYLAKE_SP = "intel.com/skylake-sp"
 
 
 class HardwareLabel(str, Enum):
@@ -278,6 +251,7 @@ class HardwareLabel(str, Enum):
     Broadwell = "intel-broadwell"
     Icelake = "intel-icelake"
     NUC_TIGER_LAKE = "intel-nuc-tiger-lake"
+    SKYLAKE_SP = "intel-skylake-sp"
 
 
 class MapHardwareTypeToVendor(str, Enum):
@@ -300,6 +274,7 @@ class MapHardwareTypeToVendor(str, Enum):
     Broadwell = HardwareVendor.INTEL.value
     Icelake = HardwareVendor.INTEL.value
     NUC_TIGER_LAKE = HardwareVendor.INTEL.value
+    SKYLAKE_SP = HardwareVendor.INTEL.value
 
 
 class MapHardwareTypeToEnvironment(str, Enum):
@@ -318,6 +293,7 @@ class MapHardwareTypeToEnvironment(str, Enum):
     SKYLAKE = HardwareEnvironment.AWS.value
     Broadwell = HardwareEnvironment.AWS.value
     Icelake = HardwareEnvironment.AWS.value
+    SKYLAKE_SP = HardwareEnvironment.AWS.value
 
     # PREMISE
     NANO = HardwareEnvironment.PREMISE.value
@@ -347,6 +323,7 @@ class MapHardwareTypeToDefaultBatchSizeList(list, Enum):
     Broadwell = get_enum_values(BatchSize)
     Icelake = get_enum_values(BatchSize)
     NUC_TIGER_LAKE = get_enum_values(BatchSize)
+    SKYLAKE_SP = get_enum_values(BatchSize)
 
 
 class HardwareImageRepository(str, Enum):
@@ -403,6 +380,7 @@ class MapHardwareTypeToGroup(str, Enum):
     SKYLAKE = HardwareGroup.CPU.value
     Broadwell = HardwareGroup.CPU.value
     Icelake = HardwareGroup.CPU.value
+    SKYLAKE_SP = HardwareGroup.CPU.value
 
     APPLE_IPHONE_A11 = HardwareGroup.CONSUMER_EDGE.value
     APPLE_IPHONE_A12 = HardwareGroup.CONSUMER_EDGE.value
@@ -416,3 +394,48 @@ class MapHardwareTypeToGroup(str, Enum):
     EXYNOS_9820 = HardwareGroup.CONSUMER_EDGE.value
     EXYNOS_990 = HardwareGroup.CONSUMER_EDGE.value
     EXYNOS_2200 = HardwareGroup.CONSUMER_EDGE.value
+
+
+def type_with_model(model: HardwareMachineModel, override_label: str = None) -> str:
+    return f"{override_label or HardwareType[model.name].value} ({model})"
+
+
+class HardwareTypeLabel(str, Enum):
+    XAVIER = "Jetson Xavier NX 16GB"
+    NANO = "Jetson Nano 4GB"
+    XAVIER_AGX = "Jetson AGX Xavier 32GB"
+    ORIN = "Jetson AGX Orin Development Kit"
+    EPYC = type_with_model(HardwareMachineModel.EPYC)
+    EPYC_7002 = type_with_model(HardwareMachineModel.EPYC_7002, f"AMD Rome {HardwareType.EPYC_7002.value}")
+    EPYC_7003 = type_with_model(HardwareMachineModel.EPYC_7003, f"AMD Milan {HardwareType.EPYC_7003.value}")
+    # Cascade_lake must me above cpu, see comment above.
+    CASCADE_LAKE = type_with_model(HardwareMachineModel.CASCADE_LAKE)
+    SKYLAKE = type_with_model(HardwareMachineModel.SKYLAKE, "Sky Lake")
+    Broadwell = type_with_model(HardwareMachineModel.Broadwell)
+    Icelake = type_with_model(HardwareMachineModel.Icelake, "Ice Lake")
+    K80 = type_with_model(HardwareMachineModel.K80)
+    V100 = type_with_model(HardwareMachineModel.V100)
+    SKYLAKE_SP = type_with_model(HardwareMachineModel.SKYLAKE_SP)
+    T4 = type_with_model(HardwareMachineModel.T4)
+    A10G = type_with_model(HardwareMachineModel.A10G)
+
+    A100_80G = HardwareType.A100_80G.value
+    A100_40G = HardwareType.A100_40G.value
+    NUC_TIGER_LAKE = HardwareType.NUC_TIGER_LAKE.value
+    HAILO8 = HardwareType.HAILO8.value
+    AMBARELLA = HardwareType.AMBARELLA.value
+    APPLE_IPHONE_A11 = HardwareType.APPLE_IPHONE_A11.value
+    APPLE_IPHONE_A12 = HardwareType.APPLE_IPHONE_A12.value
+    APPLE_IPHONE_A14 = HardwareType.APPLE_IPHONE_A14.value
+    APPLE_IPHONE_A15 = HardwareType.APPLE_IPHONE_A15.value
+    SNAPDRAGON_845 = HardwareType.SNAPDRAGON_845.value
+    SNAPDRAGON_855 = HardwareType.SNAPDRAGON_855.value
+    SNAPDRAGON_885 = HardwareType.SNAPDRAGON_885.value
+    SNAPDRAGON_8_GEN_1 = HardwareType.SNAPDRAGON_8_GEN_1.value
+    EXYNOS_9810 = HardwareType.EXYNOS_9810.value
+    EXYNOS_9820 = HardwareType.EXYNOS_9820.value
+    EXYNOS_990 = HardwareType.EXYNOS_990.value
+    EXYNOS_2200 = HardwareType.EXYNOS_2200.value
+
+    # deprecated
+    CPU = type_with_model(HardwareMachineModel.CPU)
